import { IpAddressTypes } from './ip-addresses';
import { InstanceConnectionInfo } from './instance-connection-info';
import { InstanceMetadata } from './sqladmin-fetcher';
import { SslCert } from './ssl-cert';
import { AuthTypes } from './auth-types';
interface Fetcher {
    getInstanceMetadata({ projectId, regionId, instanceId, }: InstanceConnectionInfo): Promise<InstanceMetadata>;
    getEphemeralCertificate(instanceConnectionInfo: InstanceConnectionInfo, publicKey: string, authType: AuthTypes): Promise<SslCert>;
}
interface CloudSQLInstanceOptions {
    authType: AuthTypes;
    instanceConnectionName: string;
    ipType: IpAddressTypes;
    limitRateInterval?: number;
    sqlAdminFetcher: Fetcher;
}
interface RefreshResult {
    ephemeralCert: SslCert;
    host: string;
    privateKey: string;
    serverCaCert: SslCert;
}
export declare class CloudSQLInstance {
    static getCloudSQLInstance(options: CloudSQLInstanceOptions): Promise<CloudSQLInstance>;
    private readonly ipType;
    private readonly authType;
    private readonly sqlAdminFetcher;
    private readonly limitRateInterval;
    private establishedConnection;
    private next?;
    private scheduledRefreshID?;
    private throttle?;
    readonly instanceInfo: InstanceConnectionInfo;
    ephemeralCert?: SslCert;
    host?: string;
    port: number;
    privateKey?: string;
    serverCaCert?: SslCert;
    constructor({ ipType, authType, instanceConnectionName, sqlAdminFetcher, limitRateInterval, }: CloudSQLInstanceOptions);
    private initializeRateLimiter;
    forceRefresh(): Promise<RefreshResult>;
    refresh(): Promise<RefreshResult>;
    private performRefresh;
    private isValid;
    private updateValues;
    private scheduleRefresh;
    cancelRefresh(): void;
    setEstablishedConnection(): void;
}
export {};
//# sourceMappingURL=cloud-sql-instance.d.ts.map